Documentation
¶
Index ¶
- Variables
- type Profile
- func (p Profile) ClientHelloID() utls.ClientHelloID
- func (p Profile) HTTPClient() *http.Client
- func (p Profile) Headers(dest RequestDest) http.Header
- func (p Profile) Name() string
- func (p Profile) RegisterHeaderExtensions(mediaEngine *webrtc.MediaEngine) error
- func (p Profile) SettingEngine() (webrtc.SettingEngine, error)
- func (p Profile) Transport(options TLSOptions) http.RoundTripper
- func (p Profile) UserAgent() string
- func (p Profile) WebSocketDialer(options TLSOptions) *websocket.Dialer
- func (p Profile) WithAcceptLanguage(acceptLanguage string) Profile
- func (p Profile) WithClientHelloID(clientHelloID utls.ClientHelloID) Profile
- func (p Profile) WithDTLS13Mimicry() Profile
- func (p Profile) WithDTLSGREASE() Profile
- func (p Profile) WithName(name string) Profile
- func (p Profile) WithUserAgent(userAgent string) Profile
- type RequestDest
- type TLSOptions
Constants ¶
This section is empty.
Variables ¶
var ChromeWindows = Profile{ // contains filtered or unexported fields }
Functions ¶
This section is empty.
Types ¶
type Profile ¶
type Profile struct {
// contains filtered or unexported fields
}
func (Profile) ClientHelloID ¶
func (p Profile) ClientHelloID() utls.ClientHelloID
func (Profile) HTTPClient ¶
func (Profile) RegisterHeaderExtensions ¶
func (p Profile) RegisterHeaderExtensions(mediaEngine *webrtc.MediaEngine) error
func (Profile) SettingEngine ¶
func (p Profile) SettingEngine() (webrtc.SettingEngine, error)
func (Profile) Transport ¶
func (p Profile) Transport(options TLSOptions) http.RoundTripper
func (Profile) WebSocketDialer ¶
func (p Profile) WebSocketDialer(options TLSOptions) *websocket.Dialer
func (Profile) WithAcceptLanguage ¶
func (Profile) WithClientHelloID ¶
func (p Profile) WithClientHelloID(clientHelloID utls.ClientHelloID) Profile
func (Profile) WithDTLS13Mimicry ¶
func (Profile) WithDTLSGREASE ¶
func (Profile) WithUserAgent ¶
type RequestDest ¶
type RequestDest int
const ( DestDocument RequestDest = iota DestScript DestEmpty DestWebSocket )
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
internal
|
|
|
chromehttp2
Package http2 implements the HTTP/2 protocol.
|
Package http2 implements the HTTP/2 protocol. |
|
chromehttp2/internal/httpsfv
Package httpsfv provides functionality for dealing with HTTP Structured Field Values.
|
Package httpsfv provides functionality for dealing with HTTP Structured Field Values. |
|
dtls
Package dtls implements Datagram Transport Layer Security (DTLS) 1.2
|
Package dtls implements Datagram Transport Layer Security (DTLS) 1.2 |
|
dtls/internal/ciphersuite
Package ciphersuite provides TLS ciphers as registered with IANA.
|
Package ciphersuite provides TLS ciphers as registered with IANA. |
|
dtls/internal/closer
Package closer provides signaling channel for shutdown
|
Package closer provides signaling channel for shutdown |
|
dtls/internal/config
Package config contains internal handshake configuration.
|
Package config contains internal handshake configuration. |
|
dtls/internal/errors
Package errors centralizes internal DTLS error values.
|
Package errors centralizes internal DTLS error values. |
|
dtls/internal/flight
Package flight contains shared internal flight state and helpers.
|
Package flight contains shared internal flight state and helpers. |
|
dtls/internal/flight/flight12
Package flight12 contains DTLS 1.2 flight handlers.
|
Package flight12 contains DTLS 1.2 flight handlers. |
|
dtls/internal/flight/flight13
Package flight13 contains DTLS 1.3 flight handlers.
|
Package flight13 contains DTLS 1.3 flight handlers. |
|
dtls/internal/fragmentbuffer
Package fragmentbuffer reassembles fragmented DTLS handshake messages.
|
Package fragmentbuffer reassembles fragmented DTLS handshake messages. |
|
dtls/internal/handshake
Package dtlshandshake contains DTLS handshake FSM, transcript, and key schedule helpers.
|
Package dtlshandshake contains DTLS handshake FSM, transcript, and key schedule helpers. |
|
dtls/internal/handshakecrypto
Package handshakecrypto contains internal handshake cryptography helpers.
|
Package handshakecrypto contains internal handshake cryptography helpers. |
|
dtls/internal/negotiation
Package negotiation finalizes ClientHello offers and validates handshake negotiation against them.
|
Package negotiation finalizes ClientHello offers and validates handshake negotiation against them. |
|
dtls/internal/net
Package net implements DTLS specific networking primitives.
|
Package net implements DTLS specific networking primitives. |
|
dtls/internal/net/udp
Package udp implements DTLS specific UDP networking primitives.
|
Package udp implements DTLS specific UDP networking primitives. |
|
dtls/internal/rrc
Package rrc implements RFC 9853 path validation and amplification accounting.
|
Package rrc implements RFC 9853 path validation and amplification accounting. |
|
dtls/internal/state
Package state holds the internal DTLS connection state used during and after the handshake.
|
Package state holds the internal DTLS connection state used during and after the handshake. |
|
dtls/internal/util
Package util contains small helpers used across the repo
|
Package util contains small helpers used across the repo |
|
dtls/pkg/crypto/ccm
Package ccm implements a CCM, Counter with CBC-MAC as per RFC 3610.
|
Package ccm implements a CCM, Counter with CBC-MAC as per RFC 3610. |
|
dtls/pkg/crypto/ciphersuite
Package ciphersuite defines cipher-suite descriptors, immutable record metadata, protection capabilities, and DTLS record-protection contracts.
|
Package ciphersuite defines cipher-suite descriptors, immutable record metadata, protection capabilities, and DTLS record-protection contracts. |
|
dtls/pkg/crypto/clientcertificate
Package clientcertificate provides all the support Client Certificate types
|
Package clientcertificate provides all the support Client Certificate types |
|
dtls/pkg/crypto/elliptic
Package elliptic provides elliptic curve cryptography for DTLS
|
Package elliptic provides elliptic curve cryptography for DTLS |
|
dtls/pkg/crypto/fingerprint
Package fingerprint provides a helper to create fingerprint string from certificate
|
Package fingerprint provides a helper to create fingerprint string from certificate |
|
dtls/pkg/crypto/hash
Package hash provides TLS HashAlgorithm as defined in TLS 1.2
|
Package hash provides TLS HashAlgorithm as defined in TLS 1.2 |
|
dtls/pkg/crypto/keyschedule
Package keyschedule implements DTLS 1.3's key derivation related functions
|
Package keyschedule implements DTLS 1.3's key derivation related functions |
|
dtls/pkg/crypto/prf
Package prf implements TLS 1.2 Pseudorandom functions
|
Package prf implements TLS 1.2 Pseudorandom functions |
|
dtls/pkg/crypto/selfsign
Package selfsign is a test helper that generates self signed certificate.
|
Package selfsign is a test helper that generates self signed certificate. |
|
dtls/pkg/crypto/signature
Package signature provides our implemented Signature Algorithms
|
Package signature provides our implemented Signature Algorithms |
|
dtls/pkg/crypto/signaturehash
Package signaturehash provides the SignatureHashAlgorithm as defined in TLS 1.2
|
Package signaturehash provides the SignatureHashAlgorithm as defined in TLS 1.2 |
|
dtls/pkg/net
Package net defines packet-oriented primitives that are compatible with net in the standard library.
|
Package net defines packet-oriented primitives that are compatible with net in the standard library. |
|
dtls/pkg/protocol
Package protocol provides the DTLS wire format
|
Package protocol provides the DTLS wire format |
|
dtls/pkg/protocol/alert
Package alert implements TLS alert protocol https://tools.ietf.org/html/rfc5246#section-7.2
|
Package alert implements TLS alert protocol https://tools.ietf.org/html/rfc5246#section-7.2 |
|
dtls/pkg/protocol/extension
Package extension provides TLS extension framing and payload codecs.
|
Package extension provides TLS extension framing and payload codecs. |
|
dtls/pkg/protocol/extension/dtls12
Package dtls12 implements extension payloads specific to DTLS 1.2.
|
Package dtls12 implements extension payloads specific to DTLS 1.2. |
|
dtls/pkg/protocol/extension/dtls13
Package dtls13 implements extension payloads specific to DTLS 1.3.
|
Package dtls13 implements extension payloads specific to DTLS 1.3. |
|
dtls/pkg/protocol/handshake
Package handshake provides the DTLS wire protocol for handshakes
|
Package handshake provides the DTLS wire protocol for handshakes |
|
dtls/pkg/protocol/recordlayer
Package recordlayer provides lossless DTLS datagram framing for [DTLS 1.2](https://www.rfc-editor.org/rfc/rfc6347#section-4.1) and [DTLS 1.3](https://www.rfc-editor.org/rfc/rfc9147#section-4), along with the wire header values required by record protection implementations.
|
Package recordlayer provides lossless DTLS datagram framing for [DTLS 1.2](https://www.rfc-editor.org/rfc/rfc6347#section-4.1) and [DTLS 1.3](https://www.rfc-editor.org/rfc/rfc9147#section-4), along with the wire header values required by record protection implementations. |
|
ice
Package ice implements the Interactive Connectivity Establishment (ICE) protocol defined in rfc5245.
|
Package ice implements the Interactive Connectivity Establishment (ICE) protocol defined in rfc5245. |
|
ice/internal
Package internal implements internal functionality for Pions ICE module
|
Package internal implements internal functionality for Pions ICE module |
|
ice/internal/atomic
Package atomic contains custom atomic types
|
Package atomic contains custom atomic types |
|
ice/internal/fakenet
Package fakenet contains fake network abstractions
|
Package fakenet contains fake network abstractions |
|
ice/internal/netutil
Package netutil provides network-related helpers.
|
Package netutil provides network-related helpers. |
|
ice/internal/stun
Package stun contains ICE specific STUN code
|
Package stun contains ICE specific STUN code |
|
ice/internal/taskloop
Package taskloop implements a task loop to run tasks sequentially in a separate Goroutine.
|
Package taskloop implements a task loop to run tasks sequentially in a separate Goroutine. |
|
update-deps
|
|
|
Package webrtc implements the WebRTC 1.0 as defined in W3C WebRTC specification document.
|
Package webrtc implements the WebRTC 1.0 as defined in W3C WebRTC specification document. |
|
internal/fmtp
Package fmtp implements per codec parsing of fmtp lines
|
Package fmtp implements per codec parsing of fmtp lines |
|
internal/mux
Package mux multiplexes packets on a single socket (RFC7983)
|
Package mux multiplexes packets on a single socket (RFC7983) |
|
internal/util
Package util provides auxiliary functions internally used in webrtc package
|
Package util provides auxiliary functions internally used in webrtc package |
|
pkg/media
Package media provides media writer and filters
|
Package media provides media writer and filters |
|
pkg/media/h264reader
Package h264reader implements a H264 Annex-B Reader
|
Package h264reader implements a H264 Annex-B Reader |
|
pkg/media/h264writer
Package h264writer implements H264 media container writer
|
Package h264writer implements H264 media container writer |
|
pkg/media/h265reader
Package h265reader implements a H265/HEVC Annex-B Reader
|
Package h265reader implements a H265/HEVC Annex-B Reader |
|
pkg/media/h265writer
Package h265writer implements H265/HEVC media container writer
|
Package h265writer implements H265/HEVC media container writer |
|
pkg/media/ivfreader
Package ivfreader implements IVF media container reader
|
Package ivfreader implements IVF media container reader |
|
pkg/media/ivfwriter
Package ivfwriter implements IVF media container writer
|
Package ivfwriter implements IVF media container writer |
|
pkg/media/oggreader
Package oggreader implements the Ogg media container reader
|
Package oggreader implements the Ogg media container reader |
|
pkg/media/oggwriter
Package oggwriter implements OGG media container writer
|
Package oggwriter implements OGG media container writer |
|
pkg/media/rtpdump
Package rtpdump implements the RTPDump file format documented at https://www.cs.columbia.edu/irt/software/rtptools/
|
Package rtpdump implements the RTPDump file format documented at https://www.cs.columbia.edu/irt/software/rtptools/ |
|
pkg/media/samplebuilder
Package samplebuilder provides functionality to reconstruct media frames from RTP packets.
|
Package samplebuilder provides functionality to reconstruct media frames from RTP packets. |
|
pkg/null
Package null is used to represent values where the 0 value is significant This pattern is common in ECMAScript, this allows us to maintain a matching API
|
Package null is used to represent values where the 0 value is significant This pattern is common in ECMAScript, this allows us to maintain a matching API |
|
pkg/rtcerr
Package rtcerr implements the error wrappers defined throughout the WebRTC 1.0 specifications.
|
Package rtcerr implements the error wrappers defined throughout the WebRTC 1.0 specifications. |
|
Package websocket implements the WebSocket protocol defined in RFC 6455.
|
Package websocket implements the WebSocket protocol defined in RFC 6455. |
Click to show internal directories.
Click to hide internal directories.